summaryrefslogtreecommitdiffstats
path: root/contrib/uuid/gen_uuid.c
diff options
context:
space:
mode:
authorEmmanuel Dreyfus <manu@netbsd.org>2015-04-02 15:51:30 +0200
committerVijay Bellur <vbellur@redhat.com>2015-04-04 10:48:35 -0700
commit28397cae4102ac3f08576ebaf071ad92683097e8 (patch)
tree4c8be92299a951c8a28e1dc85bf2671f60da6e08 /contrib/uuid/gen_uuid.c
parent0aebfaa349c7c68c2d59531eabae5a03a748e16a (diff)
Avoid conflict between contrib/uuid and system uuid
glusterfs relies on Linux uuid implementation, which API is incompatible with most other systems's uuid. As a result, libglusterfs has to embed contrib/uuid, which is the Linux implementation, on non Linux systems. This implementation is incompatible with systtem's built in, but the symbols have the same names. Usually this is not a problem because when we link with -lglusterfs, libc's symbols are trumped. However there is a problem when a program not linked with -lglusterfs will dlopen() glusterfs component. In such a case, libc's uuid implementation is already loaded in the calling program, and it will be used instead of libglusterfs's implementation, causing crashes. A possible workaround is to use pre-load libglusterfs in the calling program (using LD_PRELOAD on NetBSD for instance), but such a mechanism is not portable, nor is it flexible. A much better approach is to rename libglusterfs's uuid_* functions to gf_uuid_* to avoid any possible conflict. This is what this change attempts. BUG: 1206587 Change-Id: I9ccd3e13afed1c7fc18508e92c7beb0f5d49f31a Signed-off-by: Emmanuel Dreyfus <manu@netbsd.org> Reviewed-on: http://review.gluster.org/10017 Tested-by: Gluster Build System <jenkins@build.gluster.com> Reviewed-by: Niels de Vos <ndevos@redhat.com>
Diffstat (limited to 'contrib/uuid/gen_uuid.c')
-rw-r--r--contrib/uuid/gen_uuid.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/contrib/uuid/gen_uuid.c b/contrib/uuid/gen_uuid.c
index 4da0dc69b84..1ec156f76ff 100644
--- a/contrib/uuid/gen_uuid.c
+++ b/contrib/uuid/gen_uuid.c
@@ -595,7 +595,7 @@ void uuid__generate_time(uuid_t out, int *num)
uuid_pack(&uu, out);
}
-void uuid_generate_time(uuid_t out)
+void gf_uuid_generate_time(uuid_t out)
{
#ifdef TLS
THREAD_LOCAL int num = 0;
@@ -662,7 +662,7 @@ void uuid__generate_random(uuid_t out, int *num)
}
}
-void uuid_generate_random(uuid_t out)
+void gf_uuid_generate_random(uuid_t out)
{
int num = 1;
/* No real reason to use the daemon for random uuid's -- yet */
@@ -672,15 +672,15 @@ void uuid_generate_random(uuid_t out)
/*
* This is the generic front-end to uuid_generate_random and
* uuid_generate_time. It uses uuid_generate_random only if
* /dev/urandom is available, since otherwise we won't have
* high-quality randomness.
*/
-void uuid_generate(uuid_t out)
+void gf_uuid_generate(uuid_t out)
{
if (get_random_fd() >= 0)
- uuid_generate_random(out);
+ gf_uuid_generate_random(out);
else
- uuid_generate_time(out);
+ gf_uuid_generate_time(out);
}
@@ -672,15 +672,15 @@ void uuid_generate_random(uuid_t out)
/*
- * This is the generic front-end to uuid_generate_random and
- * uuid_generate_time. It uses uuid_generate_random only if
+ * This is the generic front-end to gf_uuid_generate_random and
+ * gf_uuid_generate_time. It uses gf_uuid_generate_random only if
* /dev/urandom is available, since otherwise we won't have
* high-quality randomness.